==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/ArcTPR/ts/ArcTPR_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>ArcTPR</name>
    <message>
        <location filename="../ArcTPR.js" line="+79"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>線分,弧,円または楕円を選択してください</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Point on arc</source>
        <translation>通過点</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Choose solution</source>
        <translation>ソリューション</translation>
    </message>
    <message>
        <location line="+123"/>
        <location line="+65"/>
        <source>No solution</source>
        <translation>解決法がありません</translation>
    </message>
    <message>
        <location filename="../ArcTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>半径:</translation>
    </message>
    <message>
        <location filename="../ArcTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc tangential to entity, through point with radius</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Circle2TP</name>
    <message>
        <source>First line, arc or circle</source>
        <translation type="vanished">第１の線分,弧または円</translation>
    </message>
    <message>
        <source>Second line, arc or circle</source>
        <translation type="vanished">第２の線分,弧または円</translation>
    </message>
    <message>
        <source>Point on circle line</source>
        <translation type="vanished">点</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="vanished">ソリューション</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="vanished">解決法がありません</translation>
    </message>
    <message>
        <source>Point, 2 Tan&amp;gents</source>
        <translation type="vanished">&amp;g 1点と2接線</translation>
    </message>
    <message>
        <source>Draw circle tangential to two entities, through point</source>
        <translation type="vanished">２つのエンティティに接し１点を通る円を描画</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/ArcTPR/ts/ArcTPR_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>ArcTPR</name>
    <message>
        <location filename="../ArcTPR.js" line="+79"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>線分,弧,円または楕円を選択してください</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Point on arc</source>
        <translation>通過点</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Choose solution</source>
        <translation>ソリューション</translation>
    </message>
    <message>
        <location line="+123"/>
        <location line="+65"/>
        <source>No solution</source>
        <translation>解決法がありません</translation>
    </message>
    <message>
        <location filename="../ArcTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>半径:</translation>
    </message>
    <message>
        <location filename="../ArcTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation>正接,点,半径</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc tangential to entity, through point with radius</source>
        <translation>指定した半径で点を通る、エンティティに接する弧を描く</translation>
    </message>
</context>
<context>
    <name>Circle2TP</name>
    <message>
        <source>First line, arc or circle</source>
        <translation type="vanished">第１の線分,弧または円</translation>
    </message>
    <message>
        <source>Second line, arc or circle</source>
        <translation type="vanished">第２の線分,弧または円</translation>
    </message>
    <message>
        <source>Point on circle line</source>
        <translation type="vanished">点</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="vanished">ソリューション</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="vanished">解決法がありません</translation>
    </message>
    <message>
        <source>Point, 2 Tan&amp;gents</source>
        <translation type="vanished">&amp;g 1点と2接線</translation>
    </message>
    <message>
        <source>Draw circle tangential to two entities, through point</source>
        <translation type="vanished">２つのエンティティに接し１点を通る円を描画</translation>
    </message>
</context>
</TS>
